@@ -63,6 +63,7 @@ class RevisionAdded(hook.Hook):
     __regid__ = 'trackervcs.revistion-to-ticket-state'
     __select__ = hook.Hook.__select__ & is_instance('Revision')
     events = ('after_add_entity',)
+    category = 'autoset'
 
     def __call__(self):
         repo = self.entity.repository
@@ -82,6 +83,7 @@ class ApycotEnvironmentAdded(hook.Hook):
     __regid__ = 'trackervcs.revistion-to-ticket-state'
     __select__ = hook.Hook.__select__ & hook.match_rtype('has_apycot_environment')
     events = ('after_add_relation',)
+    category = 'autoset'
 
     def __call__(self):
         project = self._cw.entity_from_eid(self.eidfrom)
@@ -89,6 +91,20 @@ class ApycotEnvironmentAdded(hook.Hook):
             projectenv = self._cw.entity_from_eid(self.eidto)
             SetSourceRepositoryOp(self._cw, project=project, projectenv=projectenv)
 
+
+# set ticket 'in-progress' when attached to a patch ############################
+
+class PatchLinkedToTicket(hook.Hook):
+    __regid__ = 'trackervcs.patch-linked-to-ticket'
+    __select__ = hook.Hook.__select__ & hook.match_rtype('patch_ticket')
+    events = ('after_add_relation',)
+    category = 'autoset'
+
+    def __call__(self):
+        ticket = self._cw.entity_from_eid(self.eidto)
+        ticket.cw_adapt_to('IWorkflowable').fire_transition_if_possible('start')
+
+
 # security propagation #########################################################
 
 tracker.S_RELS |= set(('source_repository', 'has_patch_repository',
@@ -98,6 +114,7 @@ tracker.O_RELS |= set(('patch_repository', 'point_of',))
 
 
 def registration_callback(vreg):
+    vreg.register_all(globals().values(), __name__, (RevisionAdded,))
     if vreg.config['trusted-vcs-repositories']:
         vreg.register(RevisionAdded)
 
